Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(80)

Unified Diff: webkit/quota/special_storage_policy.h

Issue 6749021: Added new fileBrowserPrivate and fileHandler extension APIs (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/quota/special_storage_policy.h
===================================================================
--- webkit/quota/special_storage_policy.h (revision 80624)
+++ webkit/quota/special_storage_policy.h (working copy)
@@ -7,6 +7,7 @@
#include "base/memory/ref_counted.h"
+class FilePath;
class GURL;
namespace quota {
@@ -27,9 +28,15 @@
// Unlimited storage is not subject to 'quotas'.
virtual bool IsStorageUnlimited(const GURL& origin) = 0;
- // Local file system access allowed via File API.
- virtual bool IsLocalFileSystemAccessAllowed(const GURL& origin) = 0;
+ // Checks if local file system access to |virtual_path| from File API is
+ // allowed from |origin|.
+ virtual bool IsLocalFileSystemAccessAllowed(const GURL& origin,
+ const FilePath& virtual_path) = 0;
+ // Grants local file system access to |virtual_path| from |origin|.
+ virtual void GrantLocalFileSystemAccess(const GURL& origin,
+ const FilePath& virtual_path) = 0;
+
protected:
friend class base::RefCountedThreadSafe<SpecialStoragePolicy>;
virtual ~SpecialStoragePolicy();

Powered by Google App Engine
This is Rietveld 408576698